# Prevent stripping
%global __spec_install_post /usr/lib/rpm/brp-compress
# Turn off debuginfo package
%global debug_package %{nil}

%ifarch %ix86
%global build_dir build32
%endif
%ifarch x86_64
%global build_dir build64
%endif

# Comment out if not a pre-release
#define	prel	beta3

%define	rel	1

Name:		memtest86+
Version:	7.00
Release:	%mkrel %{?prel:0.%prel.}%{rel}
License:	GPLv2
Summary:	Stand-alone memory tester for x86 and x86-64 computers
Group:		System/Kernel and hardware
URL:		https://memtest.org
Source0:	https://github.com/memtest86plus/memtest86plus/archive/refs/tags/v%{version}%{?prel:-%prel}.tar.gz
Source1:	20_memtest86+

ExclusiveArch:	%{ix86} x86_64
BuildRequires:	binutils
BuildRequires:	gcc
Requires(post):	drakxtools-backend
Requires(preun):drakxtools-backend
Obsoletes:      pcmemtest < 1.6

%description
Memtest86+ is a stand-alone memory tester for x86 and x86-64 architecture
computers. It provides a more thorough memory check than that provided by
BIOS memory tests.

Memtest86+ can be loaded and run either directly by a PC BIOS (legacy or UEFI)
or via an intermediate bootloader that supports the Linux 16-bit, 32-bit,
64-bit, or EFI handover boot protocol. It should work on any Pentium class or
later 32-bit or 64-bit CPU.

%prep
%setup -q -n memtest86plus-%{version}%{?prel:-%prel}
%autopatch -p1
pwd
%if %{defined prel}
  sed -i 's/GIT_HASH "unknown"/GIT_HASH "%{prel}"/' %{build_dir}/Makefile
%else
  sed -i 's/GIT_HASH "unknown"/GIT_HASH "release"/' %{build_dir}/Makefile
%endif

%build
cd %{build_dir}
# Regular build flags are not wanted for this binary
make

%install
mkdir -p %{buildroot}/boot
mkdir -p %{buildroot}/%{_sysconfdir}/grub.d

install -m644 %{build_dir}/memtest.efi -D %{buildroot}/boot/memtest
install -D -m 755 %{SOURCE1} %{buildroot}/%{_sysconfdir}/grub.d/

%post
if [ $1 -eq 1 ]; then
    if [ -x /usr/sbin/bootloader-config ]; then
        /usr/sbin/bootloader-config --action add-entry --label Memtest86+ --image /boot/memtest || :
    fi
fi
if [ -d /boot/EFI/EFI ]; then
    mkdir -p /boot/EFI/EFI/memtest
    cp /boot/memtest /boot/EFI/EFI/memtest/bootx64.efi
fi

%preun
if [ $1 -eq 0 ]; then
    if [ -x /usr/sbin/bootloader-config ]; then
        /usr/sbin/bootloader-config --action remove-entry --label Memtest86+ || :
    fi
    if [ -f /boot/memtest -a -f /boot/EFI/EFI/memtest/bootx64.efi ]; then
        if cmp -s /boot/memtest /boot/EFI/EFI/memtest/bootx64.efi; then
	    rm /boot/EFI/EFI/memtest/bootx64.efi
        fi
    fi
fi

%postun
if [ $1 -eq 0 ]; then
    # update-grub2 automatically generates menu entries, so we need to run it
    # after the image has been deleted.
    if [ -x /usr/sbin/detectloader -a -x /usr/bin/update-grub2 ]; then
        loader=$(/usr/sbin/detectloader)
        if [ x$loader = xGRUB2 ]; then
            /usr/bin/update-grub2 || :
        fi
    fi
fi

%files
%doc README.md
/boot/memtest
%{_sysconfdir}/grub.d/20_memtest86+


%changelog
* Sun Feb 25 2024 martinw <martinw> 7.00-1.mga10
+ Revision: 2044215
- New version 7.00

* Sat Feb 04 2023 martinw <martinw> 6.10-1.mga9
+ Revision: 1938180
- New version 6.10

* Sat Dec 31 2022 martinw <martinw> 6.01-1.mga9
+ Revision: 1928414
- new version v6.01
- add boot option to disable big PASS/FAIL status display

* Wed Oct 26 2022 martinw <martinw> 6.00-2.mga9
+ Revision: 1899528
- Obsolete pcmemtest.

* Tue Oct 25 2022 kekepower <kekepower> 6.00-1.mga9
+ Revision: 1899263
- Update to version 6.00 final

* Sat Sep 10 2022 martinw <martinw> 6.00-0.beta3.1.mga9
+ Revision: 1886432
- New version 6.00-beta3 (based on PCMemTest)

* Thu May 14 2020 tv <tv> 5.31-1.mga8
+ Revision: 1583686
- New version
- Dropped no-scp, no-optimization, compile-fix, crash-fix patches (all upstreamed)
- Dropped fgnu89-inline patch (probably not needed)

* Thu Feb 13 2020 umeabot <umeabot> 5.01-13.mga8
+ Revision: 1515145
- Mageia 8 Mass Rebuild

* Sun Sep 23 2018 umeabot <umeabot> 5.01-12.mga7
+ Revision: 1299517
- Mageia 7 Mass Rebuild
+ tv <tv>
- kill very old obsoletes
- adjust license

* Tue May 31 2016 tv <tv> 5.01-11.mga6
+ Revision: 1019570
- ignore %%post/preun errogs (eg, when boot loader is not yet configured, mga#18494)
- rename & sync grub2 config with FC

* Sat May 14 2016 luigiwalser <luigiwalser> 5.01-10.mga6
+ Revision: 1015533
- change requires to req(post) and req(preun) on only drakxtools-backend
+ tv <tv>
- use FC patch for gcc build fix

* Tue Mar 29 2016 barjac <barjac> 5.01-9.mga6
+ Revision: 996195
- fix conflicts for upgrades from Mga5
+ umeabot <umeabot>
- Mageia 6 Mass Rebuild

* Mon Nov 16 2015 barjac <barjac> 5.01-7.mga6
+ Revision: 903490
- move 93_memtest here from grub2 - Mga#15914
- conflict earlier grub2-common

* Sun Sep 20 2015 tv <tv> 5.01-6.mga6
+ Revision: 881728
- reorder installation (more similar to FC)
- package ELF version too
- disable stripping & debuginfo
- fixes from FC:
  o fix memory region to load (rhbz#578966)
  o reduce max-page-size on x86_64 to fit into loader limits (rhbz#620846)
- patch 50: fix build
- sync patches with FC

* Wed Jan 08 2014 pterjan <pterjan> 5.01-5.mga5
+ Revision: 565495
- Disable gcc optimisations (and fix build with -O0)

* Fri Jan 03 2014 dmorgan <dmorgan> 5.01-4.mga4
+ Revision: 564084
- Disable parallel build for the moment

* Thu Dec 12 2013 pterjan <pterjan> 5.01-3.mga4
+ Revision: 556502
- Fix access outside an array

* Mon Oct 21 2013 umeabot <umeabot> 5.01-2.mga4
+ Revision: 539723
- Mageia 4 Mass Rebuild

* Tue Oct 08 2013 dams <dams> 5.01-1.mga4
+ Revision: 492825
- new version 5.01

* Sat Jan 12 2013 umeabot <umeabot> 4.20-3.mga3
+ Revision: 359946
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Tue Dec 04 2012 dams <dams> 4.20-2.mga3
+ Revision: 326513
- add a patch to fix 7th test failure (from fedora #805813)
- clean spec file
- update %%description

* Thu Jan 27 2011 erwan <erwan> 4.20-1.mga1
+ Revision: 42181
- Fixing source path
- New release 4.20
- imported package memtest86+


* Fri Dec 03 2010 Oden Eriksson <oeriksson@mandriva.com> 4.10-2mdv2011.0
+ Revision: 606636
- rebuild

* Sun May 23 2010 Thomas Backlund <tmb@mandriva.org> 4.10-1mdv2010.1
+ Revision: 545736
- update to 4.10
- drop note about needing gcc3.3 as it's not true anymore since v4.00

* Wed Mar 17 2010 Oden Eriksson <oeriksson@mandriva.com> 4.00-2mdv2010.1
+ Revision: 523303
- rebuilt for 2010.1

* Wed Sep 23 2009 Erwan Velu <erwan@mandriva.org> 4.00-1mdv2010.0
+ Revision: 447644
- 4.00

* Mon Aug 10 2009 Thomas Backlund <tmb@mandriva.org> 2.11-1mdv2010.0
+ Revision: 414265
- fix patch0 to apply cleanly

  + Thierry Vignaud <tv@mandriva.org>
    - new release

  + Erwan Velu <erwan@mandriva.org>
    - 2.10 now requires gcc3.3

* Thu Aug 28 2008 Erwan Velu <erwan@mandriva.org> 2.01-4mdv2009.0
+ Revision: 277029
- Removing versioning on memtest. Solve #16593

* Mon Aug 11 2008 Erwan Velu <erwan@mandriva.org> 2.01-3mdv2009.0
+ Revision: 270891
- Workaround for some gcc troubles in -0s

* Tue Jun 17 2008 Thierry Vignaud <tv@mandriva.org> 2.01-2mdv2009.0
+ Revision: 223233
- rebuild

* Fri Feb 22 2008 Erwan Velu <erwan@mandriva.org> 2.01-1mdv2008.1
+ Revision: 173833
- 2.01
  X86_64 patch is now upstream

* Fri Feb 08 2008 Erwan Velu <erwan@mandriva.org> 2.00-3mdv2008.1
+ Revision: 164162
- Rebuild
- Rebuild
- Fixing 64bit build
- 2.00

* Tue Jan 15 2008 Thierry Vignaud <tv@mandriva.org> 1.70-3mdv2008.1
+ Revision: 153069
- rebuild
- rebuild
- kill re-definition of %%buildroot on Pixel's request

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot


* Mon Jan 15 2007 Erwan Velu <erwan@mandriva.org> 1.70-1mdv2007.0
+ Revision: 109081
- 1.70
- Import memtest86+

* Tue Jul 25 2006 Erwan Velu <erwan@mandriva.org> 1.65-3mdv2007.0
- rebuild as src.rpm has been lost :(

* Sun Jun 25 2006 Giuseppe Ghibò <ghibo@mandriva.com> 1.65-2mdv2007.0
- Rebuilt.

* Sun Oct 02 2005 Erwan Velu <erwan@seanodes.com> 1.65-1mdk
- 1.65

* Tue Jun 28 2005 Erwan Velu <erwan@seanodes.com> 1.60.1mdk
- 1.60

* Fri Jun 10 2005 Per Øyvind Karlsen <pkarlsen@mandriva.com> 1.55.1-1mdk
- 1.55.1
- %%mkrel

* Thu Apr 07 2005 Giuseppe Ghibò <ghibo@mandrakesoft.com> 1.55-2mdk
- Rebuilt for getting in sync both binaries and .src.rpm.

* Tue Mar 29 2005 Erwan Velu <erwan@seanodes.com> 1.55-1mdk
- 1.55

* Mon Mar 21 2005 Giuseppe Ghibò <ghibo@mandrakesoft.com< 1.51-4mdk
- Rebuilt.

* Thu Mar 10 2005 Giuseppe Ghibò <ghibo@mandrakesoft.com> 1.51-3mdk
- Rebuilt.

* Wed Feb 23 2005 Erwan Velu <velu@seanodes.com> 1.51-2mdk
- Rebuild

* Wed Feb 16 2005 Erwan Velu <velu@seanodes.com> 1.51-1mdk
- 1.51

* Thu Jan 27 2005 Giuseppe GHibò <ghibo@mandrakesoft.com> 1.50-1mdk
- Release: 1.50.

* Mon Nov 29 2004 Erwan Velu <velu@seanodes.com> 1.40-1mdk
- 1.40

* Fri Nov 12 2004 Erwan Velu <velu@seanodes.com> 1.30-1mdk
- 1.30

* Sat Oct 23 2004 Giuseppe Ghibò <ghibo@mandrakesoft.com> 1.27-1mdl
- Release: 1.27.

* Sun Sep 05 2004 Giuseppe Ghibò <ghibo@mandrakesoft.com> 1.26-1mdk
- Release: 1.26.

* Sat Jul 10 2004 Erwan Velu <erwan@mandrakesoft.com> 1.20-1mdk
- 1.20

* Fri Jul 09 2004 Pixel <pixel@mandrakesoft.com> 1.15-4mdk
- fix requires

* Wed Jul 07 2004 Pixel <pixel@mandrakesoft.com> 1.15-3mdk
- use bootloader-config instead of /usr/share/loader stuff

* Sat Jun 19 2004 Per Øyvind Karlsen <peroyvind@linux-mandrake.com> 1.15-2mdk
- opps, fix filename for loader (pixel)

* Thu Jun 17 2004 Per Øyvind Karlsen <peroyvind@linux-mandrake.com> 1.15-1mdk
- 1.15
- should build on amd64 too
- cosmetics

* Mon Mar 01 2004 Giuseppe Ghibò <ghibo@mandrakesoft.com> 1.11-2mdk
- Fixed URLs.

* Sat Feb 07 2004 Giuseppe Ghibò <ghibo@mandrakesoft.com> 1.11-1mdk
- initial release.
- Obsolete memtest86 (unmaintained)

